;;; cal-loaddefs.el --- automatically extracted autoloads
;;
;;; Code:


;;;### (autoloads nil "cal-bahai" "cal-bahai.el" (22180 39318 240078
;;;;;;  271000))
;;; Generated autoloads from cal-bahai.el

(autoload 'calendar-bahai-date-string "cal-bahai" "\
String of Bahá’í date of Gregorian DATE.
Defaults to today's date if DATE is not given.

\(fn &optional DATE)" nil nil)

(autoload 'calendar-bahai-print-date "cal-bahai" "\
Show the Bahá’í calendar equivalent of the selected date.

\(fn)" t nil)

(autoload 'calendar-bahai-goto-date "cal-bahai" "\
Move cursor to Bahá’í date DATE; echo Bahá’í date unless NOECHO is non-nil.

\(fn DATE &optional NOECHO)" t nil)

(autoload 'diary-bahai-insert-entry "cal-bahai" "\
Insert a diary entry.
For the Bahá’í date corresponding to the date indicated by point.
Prefix argument ARG makes the entry nonmarking.

\(fn ARG)" t nil)

(autoload 'diary-bahai-insert-monthly-entry "cal-bahai" "\
Insert a monthly diary entry.
For the day of the Bahá’í month corresponding to the date indicated by point.
Prefix argument ARG makes the entry nonmarking.

\(fn ARG)" t nil)

(autoload 'diary-bahai-insert-yearly-entry "cal-bahai" "\
Insert an annual diary entry.
For the day of the Bahá’í year corresponding to the date indicated by point.
Prefix argument ARG will make the entry nonmarking.

\(fn ARG)" t nil)

;;;***

;;;### (autoloads nil "cal-china" "cal-china.el" (22180 39318 240078
;;;;;;  271000))
;;; Generated autoloads from cal-china.el

(autoload 'calendar-chinese-date-string "cal-china" "\
String of Chinese date of Gregorian DATE.
Defaults to today's date if DATE is not given.

\(fn &optional DATE)" nil nil)

(autoload 'calendar-chinese-print-date "cal-china" "\
Show the Chinese date equivalents of date.

\(fn)" t nil)

(autoload 'calendar-chinese-goto-date "cal-china" "\
Move cursor to Chinese date DATE.
Echo Chinese date unless NOECHO is non-nil.

\(fn DATE &optional NOECHO)" t nil)

(autoload 'diary-chinese-mark-entries "cal-china" "\
Mark days in the calendar window that have Chinese date diary entries.
Marks each entry in `diary-file' (or included files) visible in the calendar
window.  See `diary-chinese-list-entries' for more information.

This function is provided for use with `diary-nongregorian-marking-hook'.

\(fn)" nil nil)

(autoload 'diary-chinese-list-entries "cal-china" "\
Add any Chinese date entries from the diary file to `diary-entries-list'.
Chinese date diary entries must be prefixed by `diary-chinese-entry-symbol'
\(normally a `C').  The same `diary-date-forms' govern the style
of the Chinese calendar entries.  If a Chinese date diary entry begins with
`diary-nonmarking-symbol', the entry will appear in the diary listing,
but will not be marked in the calendar.

This function is provided for use with `diary-nongregorian-listing-hook'.

\(fn)" nil nil)

(autoload 'diary-chinese-anniversary "cal-china" "\
Like `diary-anniversary' (which see) but accepts Chinese date.

\(fn MONTH DAY &optional YEAR MARK)" nil nil)

(autoload 'diary-chinese-insert-anniversary-entry "cal-china" "\
Insert an anniversary diary entry for the Chinese date at point.
Prefix argument ARG makes the entry nonmarking.

\(fn &optional ARG)" t nil)

(autoload 'diary-chinese-insert-entry "cal-china" "\
Insert a diary entry for the Chinese date at point.

\(fn &optional ARG)" t nil)

(autoload 'diary-chinese-insert-monthly-entry "cal-china" "\
Insert a monthly diary entry for the Chinese date at point.

\(fn &optional ARG)" t nil)

(autoload 'diary-chinese-insert-yearly-entry "cal-china" "\
Insert a yearly diary entry for the Chinese date at point.

\(fn &optional ARG)" t nil)

;;;***

;;;### (autoloads nil "cal-coptic" "cal-coptic.el" (22180 39318 240078
;;;;;;  271000))
;;; Generated autoloads from cal-coptic.el

(autoload 'calendar-coptic-date-string "cal-coptic" "\
String of Coptic date of Gregorian DATE.
Returns the empty string if DATE is pre-Coptic calendar.
Defaults to today's date if DATE is not given.

\(fn &optional DATE)" nil nil)

(autoload 'calendar-coptic-print-date "cal-coptic" "\
Show the Coptic calendar equivalent of the selected date.

\(fn)" t nil)

(autoload 'calendar-coptic-goto-date "cal-coptic" "\
Move cursor to Coptic date DATE.
Echo Coptic date unless NOECHO is t.

\(fn DATE &optional NOECHO)" t nil)

(autoload 'calendar-ethiopic-date-string "cal-coptic" "\
String of Ethiopic date of Gregorian DATE.
Returns the empty string if DATE is pre-Ethiopic calendar.
Defaults to today's date if DATE is not given.

\(fn &optional DATE)" nil nil)

(autoload 'calendar-ethiopic-print-date "cal-coptic" "\
Show the Ethiopic calendar equivalent of the selected date.

\(fn)" t nil)

(autoload 'calendar-ethiopic-goto-date "cal-coptic" "\
Move cursor to Ethiopic date DATE.
Echo Ethiopic date unless NOECHO is t.

\(fn DATE &optional NOECHO)" t nil)

;;;***

;;;### (autoloads nil "cal-french" "cal-french.el" (22180 39318 240078
;;;;;;  271000))
;;; Generated autoloads from cal-french.el

(autoload 'calendar-french-date-string "cal-french" "\
String of French Revolutionary date of Gregorian DATE.
Returns the empty string if DATE is pre-French Revolutionary.
Defaults to today's date if DATE is not given.

\(fn &optional DATE)" nil nil)

(autoload 'calendar-french-print-date "cal-french" "\
Show the French Revolutionary calendar equivalent of the selected date.

\(fn)" t nil)

(autoload 'calendar-french-goto-date "cal-french" "\
Move cursor to French Revolutionary date DATE.
Echo French Revolutionary date unless NOECHO is non-nil.

\(fn DATE &optional NOECHO)" t nil)

;;;***

;;;### (autoloads nil "cal-hebrew" "cal-hebrew.el" (22180 39318 241078
;;;;;;  266000))
;;; Generated autoloads from cal-hebrew.el

(autoload 'calendar-hebrew-date-string "cal-hebrew" "\
String of Hebrew date before sunset of Gregorian DATE.
Defaults to today's date if DATE is not given.
Driven by the variable `calendar-date-display-form'.

\(fn &optional DATE)" nil nil)

(autoload 'calendar-hebrew-print-date "cal-hebrew" "\
Show the Hebrew calendar equivalent of the date under the cursor.

\(fn)" t nil)

(autoload 'calendar-hebrew-goto-date "cal-hebrew" "\
Move cursor to Hebrew DATE; echo Hebrew date unless NOECHO is non-nil.

\(fn DATE &optional NOECHO)" t nil)

(autoload 'diary-hebrew-insert-entry "cal-hebrew" "\
Insert a diary entry for the Hebrew date at point.
Prefix argument ARG makes the entry nonmarking.

\(fn ARG)" t nil)

(autoload 'diary-hebrew-insert-monthly-entry "cal-hebrew" "\
Insert a monthly diary entry.
For the day of the Hebrew month corresponding to the date indicated by point.
Prefix argument ARG makes the entry nonmarking.

\(fn ARG)" t nil)

(autoload 'diary-hebrew-insert-yearly-entry "cal-hebrew" "\
Insert an annual diary entry.
For the day of the Hebrew year corresponding to the date indicated by point.
Prefix argument ARG makes the entry nonmarking.

\(fn ARG)" t nil)

;;;***

;;;### (autoloads nil "cal-html" "cal-html.el" (22180 39318 241078
;;;;;;  266000))
;;; Generated autoloads from cal-html.el

(autoload 'cal-html-cursor-month "cal-html" "\
Write an HTML calendar file for numeric MONTH of four-digit YEAR.
The output directory DIR is created if necessary.  Interactively,
MONTH and YEAR are taken from the calendar cursor position, or from
the position specified by EVENT.  Note that any existing output files
are overwritten.

\(fn MONTH YEAR DIR &optional EVENT)" t nil)

(autoload 'cal-html-cursor-year "cal-html" "\
Write HTML calendar files (index and monthly pages) for four-digit YEAR.
The output directory DIR is created if necessary.  Interactively,
YEAR is taken from the calendar cursor position, or from the position
specified by EVENT.  Note that any existing output files are overwritten.

\(fn YEAR DIR &optional EVENT)" t nil)

;;;***

;;;### (autoloads nil "cal-islam" "cal-islam.el" (22180 39318 241078
;;;;;;  266000))
;;; Generated autoloads from cal-islam.el

(autoload 'calendar-islamic-date-string "cal-islam" "\
String of Islamic date before sunset of Gregorian DATE.
Returns the empty string if DATE is pre-Islamic.
Defaults to today's date if DATE is not given.
Driven by the variable `calendar-date-display-form'.

\(fn &optional DATE)" nil nil)

(autoload 'calendar-islamic-print-date "cal-islam" "\
Show the Islamic calendar equivalent of the date under the cursor.

\(fn)" t nil)

(autoload 'calendar-islamic-goto-date "cal-islam" "\
Move cursor to Islamic DATE; echo Islamic date unless NOECHO is non-nil.

\(fn DATE &optional NOECHO)" t nil)

(autoload 'diary-islamic-insert-entry "cal-islam" "\
Insert a diary entry.
For the Islamic date corresponding to the date indicated by point.
Prefix argument ARG makes the entry nonmarking.

\(fn ARG)" t nil)

(autoload 'diary-islamic-insert-monthly-entry "cal-islam" "\
Insert a monthly diary entry.
For the day of the Islamic month corresponding to the date indicated by point.
Prefix argument ARG makes the entry nonmarking.

\(fn ARG)" t nil)

(autoload 'diary-islamic-insert-yearly-entry "cal-islam" "\
Insert an annual diary entry.
For the day of the Islamic year corresponding to the date indicated by point.
Prefix argument ARG makes the entry nonmarking.

\(fn ARG)" t nil)

;;;***

;;;### (autoloads nil "cal-iso" "cal-iso.el" (22180 39318 241078
;;;;;;  266000))
;;; Generated autoloads from cal-iso.el

(autoload 'calendar-iso-from-absolute "cal-iso" "\
Compute the `ISO commercial date' corresponding to the absolute DATE.
The ISO year corresponds approximately to the Gregorian year, but weeks
start on Monday and end on Sunday.  The first week of the ISO year is the
first such week in which at least 4 days are in a year.  The ISO commercial
date has the form (week day year) in which week is in the range 1..52 and
day is in the range 0..6 (1 = Monday, 2 = Tuesday, ..., 0 = Sunday).  The
absolute date is the number of days elapsed since the (imaginary) Gregorian
date Sunday, December 31, 1 BC.

\(fn DATE)" nil nil)

(autoload 'calendar-iso-date-string "cal-iso" "\
String of ISO date of Gregorian DATE, default today.

\(fn &optional DATE)" nil nil)

(autoload 'calendar-iso-print-date "cal-iso" "\
Show equivalent ISO date for the date under the cursor.

\(fn)" t nil)

(autoload 'calendar-iso-goto-date "cal-iso" "\
Move cursor to ISO DATE; echo ISO date unless NOECHO is non-nil.

\(fn DATE &optional NOECHO)" t nil)

(autoload 'calendar-iso-goto-week "cal-iso" "\
Move cursor to ISO DATE; echo ISO date unless NOECHO is non-nil.
Interactively, goes to the first day of the specified week.

\(fn DATE &optional NOECHO)" t nil)

;;;***

;;;### (autoloads nil "cal-julian" "cal-julian.el" (22180 39318 241078
;;;;;;  266000))
;;; Generated autoloads from cal-julian.el

(autoload 'calendar-julian-from-absolute "cal-julian" "\
Compute the Julian (month day year) corresponding to the absolute DATE.
The absolute date is the number of days elapsed since the (imaginary)
Gregorian date Sunday, December 31, 1 BC.

\(fn DATE)" nil nil)

(autoload 'calendar-julian-date-string "cal-julian" "\
String of Julian date of Gregorian DATE.
Defaults to today's date if DATE is not given.
Driven by the variable `calendar-date-display-form'.

\(fn &optional DATE)" nil nil)

(autoload 'calendar-julian-print-date "cal-julian" "\
Show the Julian calendar equivalent of the date under the cursor.

\(fn)" t nil)

(autoload 'calendar-julian-goto-date "cal-julian" "\
Move cursor to Julian DATE; echo Julian date unless NOECHO is non-nil.

\(fn DATE &optional NOECHO)" t nil)

(autoload 'calendar-astro-to-absolute "cal-julian" "\
Absolute date of astronomical (Julian) day number D.

\(fn D)" nil nil)

(autoload 'calendar-astro-from-absolute "cal-julian" "\
Astronomical (Julian) day number of absolute date D.

\(fn D)" nil nil)

(autoload 'calendar-astro-date-string "cal-julian" "\
String of astronomical (Julian) day number after noon UTC of Gregorian DATE.
Defaults to today's date if DATE is not given.

\(fn &optional DATE)" nil nil)

(autoload 'calendar-astro-print-day-number "cal-julian" "\
Show astronomical (Julian) day number after noon UTC on cursor date.

\(fn)" t nil)

(autoload 'calendar-astro-goto-day-number "cal-julian" "\
Move cursor to astronomical (Julian) DAYNUMBER.
Echo astronomical (Julian) day number unless NOECHO is non-nil.

\(fn DAYNUMBER &optional NOECHO)" t nil)

;;;***

;;;### (autoloads nil "cal-mayan" "cal-mayan.el" (22180 39318 241078
;;;;;;  266000))
;;; Generated autoloads from cal-mayan.el

(autoload 'calendar-mayan-date-string "cal-mayan" "\
String of Mayan date of Gregorian DATE; default today.

\(fn &optional DATE)" nil nil)

(autoload 'calendar-mayan-print-date "cal-mayan" "\
Show the Mayan long count, tzolkin, and haab equivalents of date.

\(fn)" t nil)

(autoload 'calendar-mayan-next-haab-date "cal-mayan" "\
Move cursor to next instance of Mayan HAAB-DATE.
Echo Mayan date unless NOECHO is non-nil.

\(fn HAAB-DATE &optional NOECHO)" t nil)

(autoload 'calendar-mayan-previous-haab-date "cal-mayan" "\
Move cursor to previous instance of Mayan HAAB-DATE.
Echo Mayan date unless NOECHO is non-nil.

\(fn HAAB-DATE &optional NOECHO)" t nil)

(autoload 'calendar-mayan-next-tzolkin-date "cal-mayan" "\
Move cursor to next instance of Mayan TZOLKIN-DATE.
Echo Mayan date unless NOECHO is non-nil.

\(fn TZOLKIN-DATE &optional NOECHO)" t nil)

(autoload 'calendar-mayan-previous-tzolkin-date "cal-mayan" "\
Move cursor to previous instance of Mayan TZOLKIN-DATE.
Echo Mayan date unless NOECHO is non-nil.

\(fn TZOLKIN-DATE &optional NOECHO)" t nil)

(autoload 'calendar-mayan-next-round-date "cal-mayan" "\
Move cursor to next instance of Mayan TZOLKIN-DATE HAAB-DATE combination.
Echo Mayan date unless NOECHO is non-nil.

\(fn TZOLKIN-DATE HAAB-DATE &optional NOECHO)" t nil)

(autoload 'calendar-mayan-previous-round-date "cal-mayan" "\
Move to previous instance of Mayan TZOLKIN-DATE HAAB-DATE combination.
Echo Mayan date unless NOECHO is non-nil.

\(fn TZOLKIN-DATE HAAB-DATE &optional NOECHO)" t nil)

(autoload 'calendar-mayan-goto-long-count-date "cal-mayan" "\
Move cursor to Mayan long count DATE.
Echo Mayan date unless NOECHO is non-nil.

\(fn DATE &optional NOECHO)" t nil)

;;;***

;;;### (autoloads nil "cal-move" "cal-move.el" (22180 39318 241078
;;;;;;  266000))
;;; Generated autoloads from cal-move.el

(autoload 'calendar-cursor-to-nearest-date "cal-move" "\
Move the cursor to the closest date.
The position of the cursor is unchanged if it is already on a date.
Returns the list (month day year) giving the cursor position.

\(fn)" nil nil)

(autoload 'calendar-cursor-to-visible-date "cal-move" "\
Move the cursor to DATE that is on the screen.

\(fn DATE)" nil nil)

(autoload 'calendar-goto-today "cal-move" "\
Reposition the calendar window so the current date is visible.

\(fn)" t nil)

(autoload 'calendar-forward-month "cal-move" "\
Move the cursor forward ARG months.
Movement is backward if ARG is negative.

\(fn ARG)" t nil)

(autoload 'calendar-forward-year "cal-move" "\
Move the cursor forward by ARG years.
Movement is backward if ARG is negative.

\(fn ARG)" t nil)

(autoload 'calendar-backward-month "cal-move" "\
Move the cursor backward by ARG months.
Movement is forward if ARG is negative.

\(fn ARG)" t nil)

(autoload 'calendar-backward-year "cal-move" "\
Move the cursor backward ARG years.
Movement is forward is ARG is negative.

\(fn ARG)" t nil)

(autoload 'calendar-scroll-left "cal-move" "\
Scroll the displayed calendar left by ARG months.
If ARG is negative the calendar is scrolled right.  Maintains the relative
position of the cursor with respect to the calendar as well as possible.
EVENT is an event like `last-nonmenu-event'.

\(fn &optional ARG EVENT)" t nil)

(autoload 'calendar-scroll-right "cal-move" "\
Scroll the displayed calendar window right by ARG months.
If ARG is negative the calendar is scrolled left.  Maintains the relative
position of the cursor with respect to the calendar as well as possible.
EVENT is an event like `last-nonmenu-event'.

\(fn &optional ARG EVENT)" t nil)

(autoload 'calendar-scroll-left-three-months "cal-move" "\
Scroll the displayed calendar window left by 3*ARG months.
If ARG is negative the calendar is scrolled right.  Maintains the relative
position of the cursor with respect to the calendar as well as possible.
EVENT is an event like `last-nonmenu-event'.

\(fn ARG &optional EVENT)" t nil)

(autoload 'calendar-scroll-toolkit-scroll "cal-move" "\
Function to scroll the calendar after a toolkit scroll-bar click.

\(fn EVENT)" t nil)

(autoload 'calendar-scroll-right-three-months "cal-move" "\
Scroll the displayed calendar window right by 3*ARG months.
If ARG is negative the calendar is scrolled left.  Maintains the relative
position of the cursor with respect to the calendar as well as possible.
EVENT is an event like `last-nonmenu-event'.

\(fn ARG &optional EVENT)" t nil)

(autoload 'calendar-forward-day "cal-move" "\
Move the cursor forward ARG days.
Moves backward if ARG is negative.

\(fn ARG)" t nil)

(autoload 'calendar-backward-day "cal-move" "\
Move the cursor back ARG days.
Moves forward if ARG is negative.

\(fn ARG)" t nil)

(autoload 'calendar-forward-week "cal-move" "\
Move the cursor forward ARG weeks.
Moves backward if ARG is negative.

\(fn ARG)" t nil)

(autoload 'calendar-backward-week "cal-move" "\
Move the cursor back ARG weeks.
Moves forward if ARG is negative.

\(fn ARG)" t nil)

(autoload 'calendar-beginning-of-week "cal-move" "\
Move the cursor back ARG calendar-week-start-day's.

\(fn ARG)" t nil)

(autoload 'calendar-end-of-week "cal-move" "\
Move the cursor forward ARG calendar-week-start-day+6's.

\(fn ARG)" t nil)

(autoload 'calendar-beginning-of-month "cal-move" "\
Move the cursor backward ARG month beginnings.

\(fn ARG)" t nil)

(autoload 'calendar-end-of-month "cal-move" "\
Move the cursor forward ARG month ends.

\(fn ARG)" t nil)

(autoload 'calendar-beginning-of-year "cal-move" "\
Move the cursor backward ARG year beginnings.

\(fn ARG)" t nil)

(autoload 'calendar-end-of-year "cal-move" "\
Move the cursor forward ARG year beginnings.

\(fn ARG)" t nil)

(autoload 'calendar-goto-date "cal-move" "\
Move cursor to DATE.

\(fn DATE)" t nil)

(autoload 'calendar-goto-day-of-year "cal-move" "\
Move cursor to YEAR, DAY number; echo DAY/YEAR unless NOECHO is non-nil.
Negative DAY counts backward from end of year.

\(fn YEAR DAY &optional NOECHO)" t nil)

;;;***

;;;### (autoloads nil "cal-persia" "cal-persia.el" (22180 39318 241078
;;;;;;  266000))
;;; Generated autoloads from cal-persia.el

(autoload 'calendar-persian-date-string "cal-persia" "\
String of Persian date of Gregorian DATE, default today.

\(fn &optional DATE)" nil nil)

(autoload 'calendar-persian-print-date "cal-persia" "\
Show the Persian calendar equivalent of the selected date.

\(fn)" t nil)

(autoload 'calendar-persian-goto-date "cal-persia" "\
Move cursor to Persian date DATE.
Echo Persian date unless NOECHO is non-nil.

\(fn DATE &optional NOECHO)" t nil)

;;;***

;;;### (autoloads nil "cal-tex" "cal-tex.el" (22180 39318 242078
;;;;;;  261000))
;;; Generated autoloads from cal-tex.el

(autoload 'cal-tex-cursor-year "cal-tex" "\
Make a buffer with LaTeX commands for the year cursor is on.
Optional prefix argument N specifies number of years.
Optional EVENT indicates a buffer position to use instead of point.

\(fn &optional N EVENT)" t nil)

(autoload 'cal-tex-cursor-year-landscape "cal-tex" "\
Make a buffer with LaTeX commands for the year cursor is on.
Optional prefix argument N specifies number of years.
Optional EVENT indicates a buffer position to use instead of point.

\(fn &optional N EVENT)" t nil)

(autoload 'cal-tex-cursor-filofax-year "cal-tex" "\
Make a Filofax one page yearly calendar of year indicated by cursor.
Optional prefix argument N specifies number of years.
Optional EVENT indicates a buffer position to use instead of point.

\(fn &optional N EVENT)" t nil)

(autoload 'cal-tex-cursor-month-landscape "cal-tex" "\
Make a LaTeX calendar buffer for the month the cursor is on.
Optional prefix argument N specifies number of months to be
produced (default 1).  The output is in landscape format, one
month to a page.  It shows holiday and diary entries if
`cal-tex-holidays' and `cal-tex-diary', respectively, are non-nil.
Optional EVENT indicates a buffer position to use instead of point.

\(fn &optional N EVENT)" t nil)

(autoload 'cal-tex-cursor-month "cal-tex" "\
Make a LaTeX calendar buffer for the month the cursor is on.
Optional prefix argument N specifies number of months to be
produced (default 1).  The calendar is condensed onto one page.
It shows holiday and diary entries if `cal-tex-holidays' and
`cal-tex-diary', respectively, are non-nil.  Optional EVENT
indicates a buffer position to use instead of point.

\(fn &optional N EVENT)" t nil)

(autoload 'cal-tex-cursor-week "cal-tex" "\
Make a one page LaTeX calendar for one week, showing hours of the day.
There are two columns; with 8-12am in the first and 1-5pm in the second.
It shows holidays if `cal-tex-holidays' is non-nil.
It does not show diary entries.

The optional prefix argument N specifies a number of weeks (default 1).

By default, the calendar is for the week at point; the optional
argument EVENT specifies a different buffer position.

\(fn &optional N EVENT)" t nil)

(autoload 'cal-tex-cursor-week2 "cal-tex" "\
Make a two page LaTeX calendar for one week, showing hours of the day.
There are two columns; with 8-12am in the first and 1-5pm in the second.
It shows holidays if `cal-tex-holidays' is non-nil.
It does not show diary entries.

The optional prefix argument N specifies a number of weeks (default 1).

By default, the calendar is for the week at point; the optional
argument EVENT specifies a different buffer position.

\(fn &optional N EVENT)" t nil)

(autoload 'cal-tex-cursor-week-iso "cal-tex" "\
Make a one page LaTeX calendar for one week, in the ISO-style.
It does not show hours of the day.
It shows holidays if `cal-tex-holidays' is non-nil.
It shows diary entries if `cal-tex-diary' is non-nil.

The optional prefix argument N specifies a number of weeks (default 1).

By default, the calendar is for the week at point; the optional
argument EVENT specifies a different buffer position.

\(fn &optional N EVENT)" t nil)

(autoload 'cal-tex-cursor-week-monday "cal-tex" "\
Make a one page LaTeX calendar for one week, showing hours of the day.
There are two columns; with M-W in the first and T-S in the second.
It shows the hours 8-12am and 1-5pm.
It shows holidays if `cal-tex-holidays' is non-nil.
It does not show diary entries.

The optional prefix argument N specifies a number of weeks (default 1).

By default, the calendar is for the week at point; the optional
argument EVENT specifies a different buffer position.

\(fn &optional N EVENT)" t nil)

(autoload 'cal-tex-cursor-week2-summary "cal-tex" "\
Make a two page LaTeX calendar for one week, with optional diary entries.
It does not show hours of the day.
It shows holidays if `cal-tex-holidays' is non-nil.
It shows diary entries if `cal-tex-diary' is non-nil.

The optional prefix argument N specifies a number of weeks (default 1).

By default, the calendar is for the week at point; the optional
argument EVENT specifies a different buffer position.

\(fn &optional N EVENT)" t nil)

(autoload 'cal-tex-cursor-filofax-2week "cal-tex" "\
Two-weeks-at-a-glance Filofax style calendar for week cursor is in.
Optional prefix argument N specifies number of weeks (default 1).
The calendar shows holiday and diary entries if
`cal-tex-holidays' and `cal-tex-diary', respectively, are non-nil.
Optional EVENT indicates a buffer position to use instead of point.

\(fn &optional N EVENT)" t nil)

(autoload 'cal-tex-cursor-filofax-week "cal-tex" "\
One-week-at-a-glance Filofax style calendar for week indicated by cursor.
Optional prefix argument N specifies number of weeks (default 1),
starting on Mondays.  The calendar shows holiday and diary entries
if `cal-tex-holidays' and `cal-tex-diary', respectively, are non-nil.
Optional EVENT indicates a buffer position to use instead of point.

\(fn &optional N EVENT)" t nil)

(autoload 'cal-tex-cursor-filofax-daily "cal-tex" "\
Day-per-page Filofax style calendar for week indicated by cursor.
Optional prefix argument N specifies number of weeks (default 1),
starting on Mondays.  The calendar shows holiday and diary
entries if `cal-tex-holidays' and `cal-tex-diary', respectively,
are non-nil.  Pages are ruled if `cal-tex-rules' is non-nil.
Optional EVENT indicates a buffer position to use instead of point.

\(fn &optional N EVENT)" t nil)

(autoload 'cal-tex-cursor-day "cal-tex" "\
Make a buffer with LaTeX commands for the day cursor is on.
Optional prefix argument N specifies number of days.  The calendar shows
the hours between `cal-tex-daily-start' and `cal-tex-daily-end', using
the 24-hour clock if `cal-tex-24' is non-nil.  Optional EVENT indicates
a buffer position to use instead of point.

\(fn &optional N EVENT)" t nil)

;;;***

;;;### (autoloads nil "cal-x" "cal-x.el" (22180 39318 242078 261000))
;;; Generated autoloads from cal-x.el

(autoload 'calendar-frame-setup "cal-x" "\
Display the calendar, and optionally the diary, in a separate frame.
CONFIG should be one of:
`calendar-only' - just the calendar, no diary
`one-frame'     - calendar and diary in a single frame
`two-frames'    - calendar and diary each in a separate frame

If CONFIG has any other value, or if the display is not capable of
multiple frames, then `calendar-basic-setup' is called.

If PROMPT is non-nil, prompt for the month and year to use.

\(fn CONFIG &optional PROMPT)" nil nil)

;;;***

;;;### (autoloads nil "diary-lib" "diary-lib.el" (22180 39318 244078
;;;;;;  252000))
;;; Generated autoloads from diary-lib.el

(autoload 'diary-live-p "diary-lib" "\
Return non-nil if the diary is being displayed.
The actual return value is a diary buffer.

\(fn)" nil nil)

(autoload 'diary-set-maybe-redraw "diary-lib" "\
Set SYMBOL's value to VALUE, and redraw the diary if necessary.
Redraws the diary if it is being displayed (note this is not the same as
just visiting the `diary-file'), and SYMBOL's value is to be changed.

\(fn SYMBOL VALUE)" nil nil)

(autoload 'diary-view-entries "diary-lib" "\
Prepare and display a buffer with diary entries.
Searches the file named in `diary-file' for entries that match
ARG days starting with the date indicated by the cursor position
in the displayed three-month calendar.

\(fn &optional ARG)" t nil)

(autoload 'diary-view-other-diary-entries "diary-lib" "\
Prepare and display buffer of diary entries from an alternative diary file.
Searches for entries that match ARG days, starting with the date indicated
by the cursor position in the displayed three-month calendar.
DFILE specifies the file to use as the diary file.

\(fn ARG DFILE)" t nil)

(autoload 'diary-show-all-entries "diary-lib" "\
Show all of the diary entries in the diary file.
This function gets rid of the selective display of the diary file so that
all entries, not just some, are visible.  If there is no diary buffer, one
is created.

\(fn)" t nil)

(autoload 'diary-mark-entries "diary-lib" "\
Mark days in the calendar window that have diary entries.
Marks each entry in the diary that is visible in the calendar window.

After marking the entries, runs `diary-nongregorian-marking-hook'
for the main diary file, and each included file.  For example,
this is the appropriate hook to process Islamic entries in all
diary files.  Next `diary-mark-entries-hook' runs, for the main diary
file only.  If not using include files, there is no difference between
these two hooks.

If the optional argument REDRAW is non-nil (which is the case
interactively, for example) then this first removes any existing diary
marks.  This is intended to deal with deleted diary entries.

\(fn &optional REDRAW)" t nil)

(autoload 'diary-make-entry "diary-lib" "\
Insert a diary entry STRING which may be NONMARKING in FILE.
If omitted, NONMARKING defaults to nil and FILE defaults to
`diary-file'.

\(fn STRING &optional NONMARKING FILE)" nil nil)

(autoload 'diary-insert-entry "diary-lib" "\
Insert a diary entry for the date indicated by point.
Prefix argument ARG makes the entry nonmarking.

\(fn ARG &optional EVENT)" t nil)

(autoload 'diary-insert-weekly-entry "diary-lib" "\
Insert a weekly diary entry for the day of the week indicated by point.
Prefix argument ARG makes the entry nonmarking.

\(fn ARG)" t nil)

(autoload 'diary-insert-monthly-entry "diary-lib" "\
Insert a monthly diary entry for the day of the month indicated by point.
Prefix argument ARG makes the entry nonmarking.

\(fn ARG)" t nil)

(autoload 'diary-insert-yearly-entry "diary-lib" "\
Insert an annual diary entry for the day of the year indicated by point.
Prefix argument ARG makes the entry nonmarking.

\(fn ARG)" t nil)

(autoload 'diary-insert-anniversary-entry "diary-lib" "\
Insert an anniversary diary entry for the date given by point.
Prefix argument ARG makes the entry nonmarking.

\(fn ARG)" t nil)

(autoload 'diary-insert-block-entry "diary-lib" "\
Insert a block diary entry for the days between the point and marked date.
Prefix argument ARG makes the entry nonmarking.

\(fn ARG)" t nil)

(autoload 'diary-insert-cyclic-entry "diary-lib" "\
Insert a cyclic diary entry starting at the date given by point.
Prefix argument ARG makes the entry nonmarking.

\(fn ARG)" t nil)

(autoload 'diary-font-lock-keywords "diary-lib" "\
Return a value for the variable `diary-font-lock-keywords'.

\(fn)" nil nil)

;;;***

;;;### (autoloads nil "holidays" "holidays.el" (22180 39318 244078
;;;;;;  252000))
;;; Generated autoloads from holidays.el

(autoload 'calendar-list-holidays "holidays" "\
Create a buffer containing the holidays for the current calendar window.
The holidays are those in the list `calendar-notable-days'.
Returns non-nil if any holidays are found.
If EVENT is non-nil, it's an event indicating the buffer position to
use instead of point.

\(fn &optional EVENT)" t nil)

(autoload 'calendar-cursor-holidays "holidays" "\
Find holidays for the date specified by the cursor in the calendar window.
Optional DATE is a list (month day year) to use instead of the
cursor position.  EVENT specifies a buffer position to use for a date.

\(fn &optional DATE EVENT)" t nil)

(autoload 'calendar-mark-holidays "holidays" "\
Mark notable days in the calendar window.
If EVENT is non-nil, it's an event indicating the buffer position to
use instead of point.

\(fn &optional EVENT)" t nil)

;;;***

;;;### (autoloads nil "lunar" "lunar.el" (22180 39318 245078 248000))
;;; Generated autoloads from lunar.el

(autoload 'calendar-lunar-phases "lunar" "\
Create a buffer with the lunar phases for the current calendar window.
If EVENT is non-nil, it's an event indicating the buffer position to
use instead of point.

\(fn &optional EVENT)" t nil)

;;;***

;;;### (autoloads nil "solar" "solar.el" (22180 39318 245078 248000))
;;; Generated autoloads from solar.el

(autoload 'calendar-sunrise-sunset "solar" "\
Local time of sunrise and sunset for date under cursor.
Accurate to a few seconds.

\(fn &optional EVENT)" t nil)

(autoload 'calendar-sunrise-sunset-month "solar" "\
Local time of sunrise and sunset for month under cursor or at EVENT.

\(fn &optional EVENT)" t nil)

;;;***

;;;### (autoloads nil nil ("appt.el" "cal-dst.el" "cal-menu.el" "calendar.el"
;;;;;;  "icalendar.el" "parse-time.el" "time-date.el" "timeclock.el"
;;;;;;  "todo-mode.el") (22180 39318 247078 239000))

;;;***

(provide 'cal-loaddefs)
;; Local Variables:
;; version-control: never
;; no-byte-compile: t
;; no-update-autoloads: t
;; coding: utf-8
;; End:
;;; cal-loaddefs.el ends here
